@@ -445,16 +445,24 @@ vips_operation_equal( VipsOperation *a, VipsOperation *b )
 	return( FALSE );
 }
 
+void *
+vips__cache_once_init( void )
+{
+	vips_cache_lock = vips_g_mutex_new();
+
+	vips_cache_table = g_hash_table_new( 
+		(GHashFunc) vips_operation_hash, 
+		(GEqualFunc) vips_operation_equal );
+
+	return( NULL ); 
+}
+
 void
 vips__cache_init( void )
 {
-	if( !vips_cache_table ) {
-		vips_cache_lock = vips_g_mutex_new();
+	static GOnce once = G_ONCE_INIT;
 
-		vips_cache_table = g_hash_table_new( 
-			(GHashFunc) vips_operation_hash, 
-			(GEqualFunc) vips_operation_equal );
-	}
+	VIPS_ONCE( &once, (GThreadFunc) vips__cache_once_init, NULL );
 }
 
 static void *
@@ -601,6 +609,10 @@ vips_cache_insert( VipsOperation *operation )
 {
 	VipsOperationCacheEntry *entry = g_new( VipsOperationCacheEntry, 1 );
 
+#ifdef VIPS_DEBUG
+	printf( "vips_cache_insert: adding %p to cache\n", operation );
+#endif /*VIPS_DEBUG*/
+
 	entry->operation = operation;
 	entry->time = 0;
 	entry->invalidate_id = 0;
@@ -756,6 +768,10 @@ vips_cache_operation_lookup( VipsOperation *operation )
 
 	g_mutex_unlock( vips_cache_lock );
 
+#ifdef VIPS_DEBUG
+	printf( "vips_cache_operation_lookup: result = %p\n", result );
+#endif /*VIPS_DEBUG*/
+
 	return( result );
 }
 
@@ -772,6 +788,11 @@ vips_cache_operation_add( VipsOperation *operation )
 
 	g_mutex_lock( vips_cache_lock );
 
+#ifdef VIPS_DEBUG
+	printf( "vips_cache_operation_add: adding " );
+	vips_object_print_dump( VIPS_OBJECT( operation ) );
+#endif /*VIPS_DEBUG*/
+
 	/* If two threads call the same operation at the same time, 
 	 * we can get multiple adds. Let the first one win. See
 	 * https://github.com/jcupitt/libvips/pull/181
@@ -824,10 +845,18 @@ vips_cache_operation_buildp( VipsOperation **operation )
 #endif /*VIPS_DEBUG*/
 
 	if( (hit = vips_cache_operation_lookup( *operation )) ) {
+#ifdef VIPS_DEBUG
+		printf( "vips_cache_operation_buildp: cache hit %p\n", hit );
+#endif /*VIPS_DEBUG*/
+
 		g_object_unref( *operation );
 		*operation = hit;
 	}
 	else {
+#ifdef VIPS_DEBUG
+		printf( "vips_cache_operation_buildp: cache miss, building\n" );
+#endif /*VIPS_DEBUG*/
+
 		if( vips_object_build( VIPS_OBJECT( *operation ) ) ) 
 			return( -1 );
 
@@ -887,6 +916,10 @@ vips_cache_set_max( int max )
  * Set the maximum amount of tracked memory we allow before we start dropping
  * cached operations. See vips_tracked_get_mem().
  *
+ * libvips only tracks memory it allocates, it can't track memory allocated by
+ * external libraries. If you use an operation like vips_magickload(), most of
+ * the memory it uses won't be included. 
+ *
  * See also: vips_tracked_get_mem(). 
  */
 void
@@ -954,6 +987,10 @@ vips_cache_get_max_mem( void )
  * Get the maximum number of tracked files we allow before we start dropping
  * cached operations. See vips_tracked_get_files().
  *
+ * libvips only tracks file descriptors it allocates, it can't track ones 
+ * allocated by external libraries. If you use an operation like 
+ * vips_magickload(), most of the descriptors it uses won't be included. 
+ *
  * See also: vips_tracked_get_files(). 
  *
  * Returns: the maximum number of tracked files we allow
